@@ -32,18 +32,18 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group(invoke_without_command=True)
-@click.version_option("78.0.5", package_name="alacorder")
+@click.version_option("78.1.7", package_name="alacorder")
 @click.pass_context
 def cli(ctx):
     """
-    ALACORDER beta 78
+    ALACORDER beta 78.1
 
     Alacorder retrieves case detail PDFs from Alacourt.com and processes them into text archives and data tables suitable for research purposes.
 
     """
     if ctx.invoked_subcommand is None:
         import PySimpleGUI as sg
-        sg.theme("SystemDefault")
+        sg.theme("DarkBlack")
         sg.set_options(font="Default 14")
         current_label = "Select a tab below to begin."
         fetch_layout = [
@@ -76,7 +76,7 @@ def cli(ctx):
                 sg.Radio("Cases", "TABLE", key="TB-CASES-", default=False), 
                 sg.Radio("All Charges", "TABLE", key="TB-CHARGES-", default=False)], 
             [sg.Radio("Disposition Charges", "TABLE", key="TB-DISPOSITION-",default=False), sg.Radio("Filing Charges", "TABLE", key="TB-FILING-",default=False),
-                sg.Radio("Fee Sheets","TABLES",key="TB-FEES-",default=False)],
+                sg.Radio("Fee Sheets","TABLE",key="TB-FEES-",default=False)],
             [sg.Checkbox("Allow Overwrite", key="TB-OVERWRITE-"), sg.Checkbox("Compress", key="TB-COMPRESS-")],
             [sg.Button("Export Table",key="TB")]] # "TB"
         append_layout = [
@@ -93,14 +93,13 @@ def cli(ctx):
             [sg.Button("Mark Query",key="MQ")]] # "MQ"
         about_layout = [
             [sg.Text("""
-        ___    __                          __         
-       /   |  / /___  _________  _________/ /__  _____
-      / /| | / / __ `/ ___/ __ \/ ___/ __  / _ \/ ___/
-     / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
-    /_/  |_/_/\__,_/\___/\____/_/   \__,_/\___/_/     
+    ___    __                          __         
+   /   |  / /___  _________  _________/ /__  _____
+  / /| | / / __ `/ ___/ __ \/ ___/ __  / _ \/ ___/
+ / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
+/_/  |_/_/\__,_/\___/\____/_/   \__,_/\___/_/     
 
-    ALACORDER beta 78.0.5\n
-    Alacorder retrieves and processes case detail PDFs\ninto data tables suitable for research purposes.""",font="Courier", pad=(10,10))],
+ALACORDER beta 78.1.7""",font="Courier 14", pad=(5,5))],[sg.Text("""Alacorder retrieves and processes case detail PDFs\ninto data tables suitable for research purposes.""",font="Default 22", pad=(10,10))],
             [sg.Text("""1.  fetch - Retrieve case detail PDFs in bulk from Alacourt.com\n2.  archive - Create full text archives from PDF directory\n3.  table - Export data tables from case archive or directory\n4.  append - Append contents of one archive to another\n5.  mark - Mark already collected cases on query template
             """, font="Courier 12", size=[65,None])],
             [sg.Text("View documentation, source code, and latest updates on GitHub (https://github.com/sbrobson959/alacorder) or PyPI (https://pypi.org/project/alacorder/). To use command line interface, run `% python -m alacorder --help` for guidance. \n\n© 2023 Sam Robson", font="Courier 12", size=[60,None])],
@@ -143,7 +142,7 @@ def cli(ctx):
                 a = alac.setinit(window['MA-INPUTPATH-'].get(),window['MA-OUTPUTPATH-'].get(),count=int(window['MA-COUNT-'].get()),archive=True,overwrite=window['MA-OVERWRITE-'].get(), append=window['MA-APPEND-'].get(), no_prompt=True,log=False)
             if event == "SQ":
                 pwd = window["SQ-PASSWORD-"].get()
-                a = alac.fetch(window['SQ-INPUTPATH-'].get(),window['SQ-OUTPUTPATH-'].get(),cID=window['SQ-CUSTOMERID-'].get(),uID=window['SQ-USERID-'].get(),pwd=pwd,qmax=int(window['SQ-MAX-'].get()),speed=int(window['SQ-SPEED-'].get()),qskip=int(window['SQ-SKIP-'].get()))
+                a = alac.fetch(window['SQ-INPUTPATH-'].get(),window['SQ-OUTPUTPATH-'].get(),cID=window['SQ-CUSTOMERID-'].get(),uID=window['SQ-USERID-'].get(),pwd=pwd,qmax=int(window['SQ-MAX-'].get()),speed=int(window['SQ-SPEED-'].get()),qskip=int(window['SQ-SKIP-'].get()),no_log=True)
             if event == "MQ":
                 a = alac.mark(window['MQ-INPUTPATH-'].get(),window['MQ-OUTPUTPATH-'].get())
             if event == "AA":
