@@ -2116,7 +2116,7 @@ def fetch(listpath, path, cID, uID, pwd, qmax=0, qskip=0, speed=1, no_log=False,
          query_writer.to_excel(listpath,sheet_name="PartySearchQuery",index=False)
    return [driver, query_writer]
 
-def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", speed=1, no_log=False, debug=False):
+def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", speed=1, no_log=False, debug=False, cID="", uID="", pwd=""):
    """
    Collect PDFs via SJIS Party Search Form from Alacourt.com
    Returns list of URLs for downloadPDF() to download
@@ -2165,11 +2165,13 @@ def party_search(driver, name = "", party_type = "", ssn="", dob="", county="",
    try:
       party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
    except selenium.common.exceptions.NoSuchElementException:
-      if not no_log:
-         click.secho("Connection error. Attempting reconnection...",fg='red')
-      driver.refresh()
-      driver.implicitly_wait(10/speed)
-      party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
+      if debug:
+         print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")
+      time.sleep(10)
+      login(driver,cID=cID,uID=uID,pwd=pwd)
+      driver.implicitly_wait(1)
+      driver.get("https:v2.alacourt.com/frmIndexSearchForm.aspx")
+
       if not no_log:
          click.secho("Successfully connected and logged into Alacourt!",bold=True)
 
@@ -2299,7 +2301,7 @@ def downloadPDF(driver, url, no_log=False, cID="", uID="", pwd="", speed=2):
    driver.implicitly_wait(0.5)
 
 
-def login(driver, cID, username, pwd, speed, no_log=False, path=""):
+def login(driver, cID, username="", uID="", pwd="", speed=1, no_log=False, path=""):
    """Login to Alacourt.com using (driver) and auth (cID, username, pwd) at (speed) for browser download to directory at (path)
    
    Args:
@@ -2333,7 +2335,7 @@ def login(driver, cID, username, pwd, speed, no_log=False, path=""):
    if not no_log:
       click.echo("Logging in...")
 
-   driver.implicitly_wait(0.5/speed)
+   driver.implicitly_wait(1)
    
    cID_box = driver.find_element(by=By.NAME, 
       value="ctl00$ContentPlaceHolder$txtCusid")
@@ -2345,11 +2347,11 @@ def login(driver, cID, username, pwd, speed, no_log=False, path=""):
    username_box.send_keys(username)
    pwd_box.send_keys(pwd)
 
-   driver.implicitly_wait(1/speed)
+   driver.implicitly_wait(1)
 
    login_button.click()
 
-   driver.implicitly_wait(1/speed)
+   driver.implicitly_wait(1)
 
    try:
       continueLogIn = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$btnContinueLogin")
@@ -2364,7 +2366,7 @@ def login(driver, cID, username, pwd, speed, no_log=False, path=""):
       click.secho("Successfully connected and logged into Alacourt!",bold=True)
 
 
-   driver.implicitly_wait(0.5/speed)
+   driver.implicitly_wait(1)
 
    return driver
 
@@ -2498,9 +2500,7 @@ def both():
    return click.style(uboth)
 
 def title():
-   utitle = """ALACORDER
-
-   Alacorder retrieves case detail PDFs from Alacourt.com and processes them into text archives and data tables suitable for research purposes.
+   utitle = """Alacorder retrieves case detail PDFs from Alacourt.com and processes them into text archives and data tables suitable for research purposes.
 
       ACCEPTED   /pdfs/path/   PDF directory           
       INPUTS:    .pkl(.xz)     Pickle archive
@@ -2514,18 +2514,14 @@ def title():
    return utitle
 
 def smalltitle():
-   usmalltitle = """ALACORDER
-
-   Alacorder retrieves case detail PDFs from Alacourt.com and processes them into text archives and data tables suitable for research purposes.
-
+   usmalltitle = """Alacorder retrieves case detail PDFs from Alacourt.com and processes them into text archives and data tables suitable for research purposes.
    """
    return usmalltitle
 
 def text_p():
    utext_p = ('''
-
    Enter path to output text file (must be .txt). 
-   ''')
+''')
    return utext_p
 
 def complete(conf, *outputs):
